package com.goldenwater.slaj.stan.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.stan.mapper.ObjStanApplMapper;
import com.goldenwater.slaj.stan.domain.ObjStanAppl;
import com.goldenwater.slaj.stan.service.IObjStanApplService;

@Service
public class ObjStanApplServiceImpl implements IObjStanApplService {
    @Autowired
    private ObjStanApplMapper objStanApplMapper;

    @Override
    public ObjStanAppl selectObjStanApplByGuid(String guid) { return objStanApplMapper.selectObjStanApplByGuid(guid); }
    @Override
    public List<ObjStanAppl> selectObjStanApplList(ObjStanAppl objStanAppl) { return objStanApplMapper.selectObjStanApplList(objStanAppl); }
    @Override
    public int insertObjStanAppl(ObjStanAppl objStanAppl) { return objStanApplMapper.insertObjStanAppl(objStanAppl); }
    @Override
    public int updateObjStanAppl(ObjStanAppl objStanAppl) { return objStanApplMapper.updateObjStanAppl(objStanAppl); }
    @Override
    public int deleteObjStanApplByGuid(String guid) { return objStanApplMapper.deleteObjStanApplByGuid(guid); }
    @Override
    public int deleteObjStanApplByGuids(String[] guids) { return objStanApplMapper.deleteObjStanApplByGuids(guids); }
}
